// Copyright (c) 1997  ETH Zurich (Switzerland).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org).
//
// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Polyhedron/include/CGAL/IO/Polyhedron_VRML_1_ostream.h $
// $Id: Polyhedron_VRML_1_ostream.h 580a1ef 2020-05-22T15:31:50+02:00 Mael Rouxel-Labbé
// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>

#ifndef CGAL_IO_POLYHEDRON_VRML_1_OSTREAM_H
#define CGAL_IO_POLYHEDRON_VRML_1_OSTREAM_H

#include <CGAL/license/Polyhedron.h>

// VRML_1 derives from inventor_ostream and will use that one
#include <CGAL/IO/Polyhedron_inventor_ostream.h>

#endif // CGAL_IO_POLYHEDRON_VRML_1_OSTREAM_H
